@@ -40,7 +40,6 @@
 
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
-#include <gtk/gtkbindings.h>
 #include <glib/gi18n-lib.h>
 
 #include "gdict-defbox.h"
@@ -190,23 +189,9 @@ gdict_defbox_dispose (GObject *gobject)
       priv->buffer = NULL;
     }
 
-  if (priv->busy_cursor)
-    {
-      gdk_cursor_unref (priv->busy_cursor);
-      priv->busy_cursor = NULL;
-    }
-
-  if (priv->hand_cursor)
-    {
-      gdk_cursor_unref (priv->hand_cursor);
-      priv->hand_cursor = NULL;
-    }
-
-  if (priv->regular_cursor)
-    {
-      gdk_cursor_unref (priv->regular_cursor);
-      priv->regular_cursor = NULL;
-    }
+  g_clear_object (&priv->busy_cursor);
+  g_clear_object (&priv->hand_cursor);
+  g_clear_object (&priv->regular_cursor);
 
   G_OBJECT_CLASS (gdict_defbox_parent_class)->dispose (gobject);
 }
@@ -1458,7 +1443,7 @@ follow_if_is_link (GdictDefbox *defbox,
         {
           GtkTextBuffer *buffer = gtk_text_view_get_buffer (text_view);
           GtkTextIter start, end;
-          gchar *link;
+          gchar *link_str;
 
           start = *iter;
           end = *iter;
@@ -1466,11 +1451,11 @@ follow_if_is_link (GdictDefbox *defbox,
           gtk_text_iter_backward_to_tag_toggle (&start, tag);
           gtk_text_iter_forward_to_tag_toggle (&end, tag);
 
-          link = gtk_text_buffer_get_text (buffer, &start, &end, FALSE);
+          link_str = gtk_text_buffer_get_text (buffer, &start, &end, FALSE);
 
-          g_signal_emit (defbox, gdict_defbox_signals[LINK_CLICKED], 0, link);
+          g_signal_emit (defbox, gdict_defbox_signals[LINK_CLICKED], 0, link_str);
 
-          g_free (link);
+          g_free (link_str);
           g_free (name);
           
           break;
@@ -1591,7 +1576,7 @@ defbox_motion_notify_cb (GtkWidget      *text_view,
 
   set_cursor_if_appropriate (defbox, GTK_TEXT_VIEW (text_view), bx, by);
 
-  gdk_window_get_pointer (text_view->window, NULL, NULL, NULL);
+  gdk_window_get_pointer (gtk_widget_get_window (text_view), NULL, NULL, NULL);
 
   return FALSE;
 }
@@ -1604,7 +1589,7 @@ defbox_visibility_notify_cb (GtkWidget          *text_view,
   gint wx, wy;
   gint bx, by;
 
-  gdk_window_get_pointer (text_view->window, &wx, &wy, NULL);
+  gdk_window_get_pointer (gtk_widget_get_window (text_view), &wx, &wy, NULL);
 
   gtk_text_view_window_to_buffer_coords (GTK_TEXT_VIEW (text_view),
                                          GTK_TEXT_WINDOW_WIDGET,
@@ -1889,21 +1874,21 @@ gdict_defbox_class_init (GdictDefboxClass *klass)
   
   binding_set = gtk_binding_set_by_class (klass);
   gtk_binding_entry_add_signal (binding_set,
-  			        GDK_f, GDK_CONTROL_MASK,
-  			        "show-find",
-  			        0);
+			        GDK_KEY_f, GDK_CONTROL_MASK,
+			        "show-find",
+			        0);
   gtk_binding_entry_add_signal (binding_set,
-  			        GDK_g, GDK_CONTROL_MASK,
-  			        "find-next",
-  			        0);
+			        GDK_KEY_g, GDK_CONTROL_MASK,
+			        "find-next",
+			        0);
   gtk_binding_entry_add_signal (binding_set,
-  				GDK_g, GDK_SHIFT_MASK | GDK_CONTROL_MASK,
-  				"find-previous",
-  				0);
+				GDK_KEY_g, GDK_SHIFT_MASK | GDK_CONTROL_MASK,
+				"find-previous",
+				0);
   gtk_binding_entry_add_signal (binding_set,
-  			        GDK_Escape, 0,
-  			        "hide-find",
-  			        0);
+			        GDK_KEY_Escape, 0,
+			        "hide-find",
+			        0);
 
   g_type_class_add_private (klass, sizeof (GdictDefboxPrivate));
 }
@@ -2298,13 +2283,13 @@ gdict_defbox_insert_body (GdictDefbox *defbox,
           if (end && *end == '}')
             {
               const gchar *rest;
-              gchar *link;
+              gchar *link_str;
 
-              rest = escape_link (w, &link);
+              rest = escape_link (w, &link_str);
 
               gtk_text_buffer_insert_with_tags_by_name (priv->buffer,
                                                         &end_iter,
-                                                        link, -1,
+                                                        link_str, -1,
                                                         "link",
                                                         NULL);
 
@@ -2313,7 +2298,7 @@ gdict_defbox_insert_body (GdictDefbox *defbox,
               gtk_text_buffer_get_end_iter (priv->buffer, &end_iter);
               gtk_text_buffer_insert (priv->buffer, &end_iter, " ", 1);
 
-              g_free (link);
+              g_free (link_str);
 
               continue;
             }
@@ -2342,20 +2327,20 @@ gdict_defbox_insert_body (GdictDefbox *defbox,
               if (end && *end == '}')
                 {
                   const gchar *rest;
-                  gchar *link;
+                  gchar *link_str;
 
-                  rest = escape_link (next, &link);
+                  rest = escape_link (next, &link_str);
 
                   gtk_text_buffer_insert_with_tags_by_name (priv->buffer,
                                                             &end_iter,
-                                                            link, -1,
+                                                            link_str, -1,
                                                             "link",
                                                             NULL);
 
                   gtk_text_buffer_insert (priv->buffer, &end_iter, rest, -1);
                   gtk_text_buffer_insert (priv->buffer, &end_iter, " ", 1);
 
-                  g_free (link);
+                  g_free (link_str);
                 }
 
               g_free (next);
@@ -2854,7 +2839,11 @@ gdict_defbox_set_font_name (GdictDefbox *defbox,
   else
     font_desc = NULL;
 
+#if GTK_CHECK_VERSION (2, 91, 6)
+  gtk_widget_override_font (priv->text_view, font_desc);
+#else
   gtk_widget_modify_font (priv->text_view, font_desc);
+#endif
 
   if (font_desc)
     pango_font_description_free (font_desc);
