@@ -23,7 +23,6 @@
 
 #include "screenshot-dialog.h"
 #include "screenshot-save.h"
-#include <gdk/gdkkeysyms.h>
 #include <glib/gi18n.h>
 #include <gio/gio.h>
 
@@ -51,23 +50,10 @@ struct ScreenshotDialog
   gint drag_y;
 };
 
-static gboolean
-on_toplevel_key_press_event (GtkWidget *widget,
-			     GdkEventKey *key)
-{
-  if (key->keyval == GDK_F1)
-    {
-      gtk_dialog_response (GTK_DIALOG (widget), GTK_RESPONSE_HELP);
-      return TRUE;
-    }
-
-  return FALSE;
-}
-
 static void
-on_preview_expose_event (GtkWidget      *drawing_area,
-			 GdkEventExpose *event,
-			 gpointer        data)
+on_preview_draw (GtkWidget      *drawing_area,
+                 cairo_t        *cr,
+                 gpointer        data)
 {
   ScreenshotDialog *dialog = data;
   GdkPixbuf *pixbuf = NULL;
@@ -83,8 +69,8 @@ on_preview_expose_event (GtkWidget      *drawing_area,
       gtk_icon_source_set_pixbuf (source, dialog->preview_image);
       gtk_icon_source_set_size (source, GTK_ICON_SIZE_SMALL_TOOLBAR);
       gtk_icon_source_set_size_wildcarded (source, FALSE);
-                  
-      pixbuf = gtk_style_render_icon (drawing_area->style,
+
+      pixbuf = gtk_style_render_icon (gtk_widget_get_style (drawing_area),
 				      source,
 				      gtk_widget_get_direction (drawing_area),
 				      gtk_widget_get_state (drawing_area),
@@ -98,19 +84,9 @@ on_preview_expose_event (GtkWidget      *drawing_area,
     {
       pixbuf = g_object_ref (dialog->preview_image);
     }
-  
-  /* FIXME: Draw it insensitive in that case */
-  gdk_draw_pixbuf (drawing_area->window,
-		   drawing_area->style->white_gc,
-		   pixbuf,
-		   event->area.x,
-		   event->area.y,
-		   event->area.x,
-		   event->area.y,
-		   event->area.width,
-		   event->area.height,
-		   GDK_RGB_DITHER_NORMAL,
-		   0, 0);
+
+  gdk_cairo_set_source_pixbuf (cr, pixbuf, 0, 0);
+  cairo_paint (cr);
 
   g_object_unref (pixbuf);
 }
@@ -270,8 +246,7 @@ screenshot_dialog_new (GdkPixbuf *screenshot,
 			gdk_pixbuf_get_width (screenshot)/
 			(gfloat) gdk_pixbuf_get_height (screenshot),
 			FALSE);
-  g_signal_connect (toplevel, "key_press_event", G_CALLBACK (on_toplevel_key_press_event), dialog);
-  g_signal_connect (preview_darea, "expose_event", G_CALLBACK (on_preview_expose_event), dialog);
+  g_signal_connect (preview_darea, "draw", G_CALLBACK (on_preview_draw), dialog);
   g_signal_connect (preview_darea, "button_press_event", G_CALLBACK (on_preview_button_press_event), dialog);
   g_signal_connect (preview_darea, "button_release_event", G_CALLBACK (on_preview_button_release_event), dialog);
   g_signal_connect (preview_darea, "configure_event", G_CALLBACK (on_preview_configure_event), dialog);
@@ -383,20 +358,22 @@ screenshot_dialog_set_busy (ScreenshotDialog *dialog,
 			    gboolean          busy)
 {
   GtkWidget *toplevel;
+  GdkWindow *window;
 
   toplevel = screenshot_dialog_get_toplevel (dialog);
+  window = gtk_widget_get_window (toplevel);
 
   if (busy)
     {
       GdkCursor *cursor;
       /* Change cursor to busy */
       cursor = gdk_cursor_new (GDK_WATCH);
-      gdk_window_set_cursor (toplevel->window, cursor);
+      gdk_window_set_cursor (window, cursor);
       gdk_cursor_unref (cursor);
     }
   else
     {
-      gdk_window_set_cursor (toplevel->window, NULL);
+      gdk_window_set_cursor (window, NULL);
     }
 
   gtk_widget_set_sensitive (toplevel, ! busy);
